summaryrefslogtreecommitdiffstats
path: root/konsole
diff options
context:
space:
mode:
Diffstat (limited to 'konsole')
-rw-r--r--konsole/README.ports1
-rw-r--r--konsole/konsole/CMakeLists.txt2
-rw-r--r--konsole/konsole/TEPty.cpp2
-rw-r--r--konsole/konsole/keytrans.cpp2
-rw-r--r--konsole/konsole/konsole.cpp40
-rw-r--r--konsole/konsole/konsole_part.cpp10
-rw-r--r--konsole/konsole/konsolebookmarkhandler.cpp4
-rw-r--r--konsole/konsole/konsolebookmarkmenu.cpp2
-rw-r--r--konsole/konsole/kwrited.cpp2
-rw-r--r--konsole/konsole/main.cpp6
-rw-r--r--konsole/konsole/schema.cpp6
-rw-r--r--konsole/konsole/session.cpp12
-rw-r--r--konsole/konsole/session.h4
-rw-r--r--konsole/terminalhere/terminalhere.cpp2
14 files changed, 47 insertions, 48 deletions
diff --git a/konsole/README.ports b/konsole/README.ports
index 06c3b6c13..71f3ae154 100644
--- a/konsole/README.ports
+++ b/konsole/README.ports
@@ -19,7 +19,6 @@ Lars Doelle <[email protected]>
Platform Experts
----------------
-- Tru64 - Thomas Leitner <[email protected]>
- Solaris - Stephan Kulow <[email protected]>
- FreeBSD - ?
- HP-UX - ?
diff --git a/konsole/konsole/CMakeLists.txt b/konsole/konsole/CMakeLists.txt
index 4f6c9285d..26fa93d70 100644
--- a/konsole/konsole/CMakeLists.txt
+++ b/konsole/konsole/CMakeLists.txt
@@ -78,5 +78,5 @@ set( ${target}_SRCS
tde_add_tdeinit_executable( ${target} AUTOMOC
SOURCES ${${target}_SRCS}
- LINK tdeprint-shared tdeio-shared ${XRENDER_LIBRARIES} ${DL_LIBRARIES}
+ LINK tdeprint-shared tdeio-shared ${XRENDER_LIBRARIES} ${CMAKE_DL_LIBS}
)
diff --git a/konsole/konsole/TEPty.cpp b/konsole/konsole/TEPty.cpp
index fbb152289..5e7aefa5b 100644
--- a/konsole/konsole/TEPty.cpp
+++ b/konsole/konsole/TEPty.cpp
@@ -80,7 +80,7 @@
#include <errno.h>
#include <termios.h>
-#include <kstandarddirs.h>
+#include <tdestandarddirs.h>
#include <tdelocale.h>
#include <kdebug.h>
#include <kpty.h>
diff --git a/konsole/konsole/keytrans.cpp b/konsole/konsole/keytrans.cpp
index 7a2b3f566..6400598f6 100644
--- a/konsole/konsole/keytrans.cpp
+++ b/konsole/konsole/keytrans.cpp
@@ -30,7 +30,7 @@
#include <tqobject.h>
#include <tqintdict.h>
#include <tqfile.h>
-#include <kstandarddirs.h>
+#include <tdestandarddirs.h>
#include <tdelocale.h>
#include <stdio.h>
diff --git a/konsole/konsole/konsole.cpp b/konsole/konsole/konsole.cpp
index c327c9fcf..b28256e55 100644
--- a/konsole/konsole/konsole.cpp
+++ b/konsole/konsole/konsole.cpp
@@ -99,7 +99,7 @@ Time to start a requirement list.
#include <tdefontdialog.h>
#include <kkeydialog.h>
-#include <kstandarddirs.h>
+#include <tdestandarddirs.h>
#include <tqpainter.h>
#include <tdemenubar.h>
#include <tdemessagebox.h>
@@ -331,7 +331,7 @@ Konsole::Konsole(const char* name, int histon, bool menubaron, bool tabbaron, bo
if (isRestored) {
n_tabbar = wanted_tabbar;
- TDEConfig *c = TDEApplication::kApplication()->sessionConfig();
+ TDEConfig *c = tdeApp->sessionConfig();
// c->setDesktopGroup(); // Reads from wrong group
b_dynamicTabHide = c->readBoolEntry("DynamicTabHide", false);
}
@@ -359,9 +359,9 @@ Konsole::Konsole(const char* name, int histon, bool menubaron, bool tabbaron, bo
if (te) te->setScrollbarLocation(TEWidget::SCRNONE);
}
-// connect(kapp, TQ_SIGNAL(tdedisplayFontChanged()), this, TQ_SLOT(slotFontChanged()));
+// connect(tdeApp, TQ_SIGNAL(tdedisplayFontChanged()), this, TQ_SLOT(slotFontChanged()));
- kapp->dcopClient()->setDefaultObject( "konsole" );
+ tdeApp->dcopClient()->setDefaultObject( "konsole" );
}
@@ -506,7 +506,7 @@ void Konsole::makeGUI()
TDEActionCollection* actions = actionCollection();
// Send Signal Menu -------------------------------------------------------------
- if (kapp->authorizeTDEAction("send_signal"))
+ if (tdeApp->authorizeTDEAction("send_signal"))
{
m_signals = new TDEPopupMenu(this);
m_signals->insertItem( i18n( "&Suspend Task" ) + " (STOP)", SIGSTOP);
@@ -668,11 +668,11 @@ void Konsole::makeGUI()
selectSetEncoding->setCurrentItem (0);
selectSetEncoding->plug(m_options);
- if (kapp->authorizeTDEAction("keyboard"))
+ if (tdeApp->authorizeTDEAction("keyboard"))
m_options->insertItem( SmallIconSet( "key_bindings" ), i18n( "&Keyboard" ), m_keytab );
// Schema
- if (kapp->authorizeTDEAction("schema"))
+ if (tdeApp->authorizeTDEAction("schema"))
m_options->insertItem( SmallIconSet( "colorize" ), i18n( "Sch&ema" ), m_schema);
// Select size
@@ -960,7 +960,7 @@ void Konsole::makeTabWidget()
connect(tabwidget, TQ_SIGNAL(contextMenu(const TQPoint &)),
TQ_SLOT(slotTabbarContextMenu(const TQPoint &)));
- if (kapp->authorize("shell_access")) {
+ if (tdeApp->authorize("shell_access")) {
connect(tabwidget, TQ_SIGNAL(mouseDoubleClick()), TQ_SLOT(newSession()));
m_newSessionButton = new TQToolButton( tabwidget );
@@ -1016,7 +1016,7 @@ bool Konsole::eventFilter( TQObject *o, TQEvent *ev )
void Konsole::makeBasicGUI()
{
- if (kapp->authorize("shell_access")) {
+ if (tdeApp->authorize("shell_access")) {
m_tabbarSessionsCommands = new TDEPopupMenu( this );
TDEAcceleratorManager::manage( m_tabbarSessionsCommands );
connect(m_tabbarSessionsCommands, TQ_SIGNAL(activated(int)), TQ_SLOT(newSessionTabbar(int)));
@@ -1028,7 +1028,7 @@ void Konsole::makeBasicGUI()
TDEAcceleratorManager::manage( m_edit );
m_view = new TDEPopupMenu(this);
TDEAcceleratorManager::manage( m_view );
- if (kapp->authorizeTDEAction("bookmarks"))
+ if (tdeApp->authorizeTDEAction("bookmarks"))
{
bookmarkHandler = new KonsoleBookmarkHandler( this, true );
m_bookmarks = bookmarkHandler->menu();
@@ -1036,20 +1036,20 @@ void Konsole::makeBasicGUI()
bookmarks_menu_check();
}
- if (kapp->authorizeTDEAction("settings")) {
+ if (tdeApp->authorizeTDEAction("settings")) {
m_options = new TDEPopupMenu(this);
TDEAcceleratorManager::manage( m_options );
}
- if (kapp->authorizeTDEAction("help"))
+ if (tdeApp->authorizeTDEAction("help"))
m_help = helpMenu(0, false);
- if (kapp->authorizeTDEAction("konsole_rmb")) {
+ if (tdeApp->authorizeTDEAction("konsole_rmb")) {
m_rightButton = new TDEPopupMenu(this);
TDEAcceleratorManager::manage( m_rightButton );
}
- if (kapp->authorizeTDEAction("bookmarks"))
+ if (tdeApp->authorizeTDEAction("bookmarks"))
{
// Bookmarks that open new sessions.
bookmarkHandlerSession = new KonsoleBookmarkHandler( this, false );
@@ -1133,7 +1133,7 @@ void Konsole::makeBasicGUI()
m_renameSession = new TDEAction(i18n("&Rename Session..."), TQt::CTRL+TQt::SHIFT+TQt::Key_R, this,
TQ_SLOT(slotRenameSession()), m_shortcuts, "rename_session");
- if (kapp->authorizeTDEAction("zmodem_upload"))
+ if (tdeApp->authorizeTDEAction("zmodem_upload"))
m_zmodemUpload = new TDEAction( i18n( "&ZModem Upload..." ),
TQt::CTRL+TQt::ALT+TQt::Key_U, this,
TQ_SLOT( slotZModemUpload() ),
@@ -1239,7 +1239,7 @@ void Konsole::activateMenu()
*/
bool Konsole::queryClose()
{
- if(kapp->sessionSaving())
+ if(tdeApp->sessionSaving())
// saving session - do not even think about doing any kind of cleanup here
return true;
@@ -3394,7 +3394,7 @@ void Konsole::buildSessionMenus()
createSessionMenus();
- if (kapp->authorizeTDEAction("file_print"))
+ if (tdeApp->authorizeTDEAction("file_print"))
{
m_session->insertSeparator();
m_print->plug(m_session);
@@ -3494,7 +3494,7 @@ void Konsole::loadSessionCommands()
cmd_serial = 99;
cmd_first_screen = -1;
- if (!kapp->authorize("shell_access"))
+ if (!tdeApp->authorize("shell_access"))
return;
addSessionCommand(TQString::null);
@@ -3583,7 +3583,7 @@ void Konsole::addScreenSession(const TQString &path, const TQString &socket)
void Konsole::loadScreenSessions()
{
- if (!kapp->authorize("shell_access"))
+ if (!tdeApp->authorize("shell_access"))
return;
TQCString screenDir = getenv("SCREENDIR");
if (screenDir.isEmpty())
@@ -4230,7 +4230,7 @@ void Konsole::slotZModemUpload()
void Konsole::slotZModemDetected(TESession *session)
{
- if (!kapp->authorize("zmodem_download")) return;
+ if (!tdeApp->authorize("zmodem_download")) return;
if(se != session)
activateSession(session);
diff --git a/konsole/konsole/konsole_part.cpp b/konsole/konsole/konsole_part.cpp
index be904d31b..ca275d40b 100644
--- a/konsole/konsole/konsole_part.cpp
+++ b/konsole/konsole/konsole_part.cpp
@@ -325,14 +325,14 @@ void konsolePart::emitOpenURLRequest(const TQString &cwd)
void konsolePart::makeGUI()
{
- if (!kapp->authorizeTDEAction("konsole_rmb"))
+ if (!tdeApp->authorizeTDEAction("konsole_rmb"))
return;
actions = new TDEActionCollection( (TDEMainWindow*)parentWidget );
settingsActions = new TDEActionCollection( (TDEMainWindow*)parentWidget );
// Send Signal Menu -------------------------------------------------------------
- if (kapp->authorizeTDEAction("send_signal"))
+ if (tdeApp->authorizeTDEAction("send_signal"))
{
m_signals = new TDEPopupMenu((TDEMainWindow*)parentWidget);
m_signals->insertItem( i18n( "&Suspend Task" ) + " (STOP)", SIGSTOP);
@@ -347,7 +347,7 @@ void konsolePart::makeGUI()
}
// Settings Menu ----------------------------------------------------------------
- if (kapp->authorizeTDEAction("settings"))
+ if (tdeApp->authorizeTDEAction("settings"))
{
m_options = new TDEPopupMenu((TDEMainWindow*)parentWidget);
@@ -388,7 +388,7 @@ void konsolePart::makeGUI()
selectSetEncoding->plug(m_options);
// Keyboard Options Menu ---------------------------------------------------
- if (kapp->authorizeTDEAction("keyboard"))
+ if (tdeApp->authorizeTDEAction("keyboard"))
{
m_keytab = new TDEPopupMenu((TDEMainWindow*)parentWidget);
m_keytab->setCheckable(true);
@@ -397,7 +397,7 @@ void konsolePart::makeGUI()
}
// Schema Options Menu -----------------------------------------------------
- if (kapp->authorizeTDEAction("schema"))
+ if (tdeApp->authorizeTDEAction("schema"))
{
m_schema = new TDEPopupMenu((TDEMainWindow*)parentWidget);
m_schema->setCheckable(true);
diff --git a/konsole/konsole/konsolebookmarkhandler.cpp b/konsole/konsole/konsolebookmarkhandler.cpp
index 16f8afb63..8316455ac 100644
--- a/konsole/konsole/konsolebookmarkhandler.cpp
+++ b/konsole/konsole/konsolebookmarkhandler.cpp
@@ -19,7 +19,7 @@
// Born as tdelibs/tdeio/tdefile/tdefilebookmarkhandler.cpp
#include <tdepopupmenu.h>
-#include <kstandarddirs.h>
+#include <tdestandarddirs.h>
#include <kshell.h>
#include <tdeio/job.h>
#include <tdeio/netaccess.h>
@@ -55,7 +55,7 @@ KonsoleBookmarkHandler::KonsoleBookmarkHandler( Konsole *konsole, bool toplevel
m_file = locateLocal( "data", "konsole/bookmarks.xml" );
KBookmarkManager *manager = KBookmarkManager::managerForFile( m_file, false);
- manager->setEditorOptions(kapp->caption(), false);
+ manager->setEditorOptions(tdeApp->caption(), false);
manager->setUpdate( true );
manager->setShowNSBookmarks( false );
diff --git a/konsole/konsole/konsolebookmarkmenu.cpp b/konsole/konsole/konsolebookmarkmenu.cpp
index d199808df..d52175b0e 100644
--- a/konsole/konsole/konsolebookmarkmenu.cpp
+++ b/konsole/konsole/konsolebookmarkmenu.cpp
@@ -17,7 +17,7 @@
*/
#include <tdepopupmenu.h>
-#include <kstandarddirs.h>
+#include <tdestandarddirs.h>
#include <tdeaction.h>
#include "konsole.h"
diff --git a/konsole/konsole/kwrited.cpp b/konsole/konsole/kwrited.cpp
index d889ace7b..6aea6d6a4 100644
--- a/konsole/konsole/kwrited.cpp
+++ b/konsole/konsole/kwrited.cpp
@@ -39,7 +39,7 @@
#include <tdelocale.h>
#include <tdeglobalsettings.h>
#include <kdebug.h>
-#include <kcrash.h>
+#include <tdecrash.h>
#include <kpty.h>
#include <kuser.h>
#include <tdeglobal.h>
diff --git a/konsole/konsole/main.cpp b/konsole/konsole/main.cpp
index 9e5cca6de..21bbbe66c 100644
--- a/konsole/konsole/main.cpp
+++ b/konsole/konsole/main.cpp
@@ -37,7 +37,7 @@
#include <tdecmdlineargs.h>
#include <kimageio.h>
#include <kdebug.h>
-#include <kstandarddirs.h>
+#include <tdestandarddirs.h>
#include <tdeglobalsettings.h>
#include <tdeio/netaccess.h>
#include <tdemessagebox.h>
@@ -289,7 +289,7 @@ extern "C" int TDE_EXPORT kdemain(int argc, char* argv[])
eargs.append( args->arg(i) );
if (title.isEmpty() &&
- (kapp->caption() == kapp->aboutData()->programName()))
+ (tdeApp->caption() == tdeApp->aboutData()->programName()))
{
title = TQFile::decodeName(shell); // program executed in the title bar
}
@@ -413,7 +413,7 @@ extern "C" int TDE_EXPORT kdemain(int argc, char* argv[])
}
}
- if (!kapp->authorizeTDEAction("size"))
+ if (!tdeApp->authorizeTDEAction("size"))
fixed_size = true;
// ///////////////////////////////////////////////
diff --git a/konsole/konsole/schema.cpp b/konsole/konsole/schema.cpp
index 8778a1ee9..cf80136f3 100644
--- a/konsole/konsole/schema.cpp
+++ b/konsole/konsole/schema.cpp
@@ -55,7 +55,7 @@
#include <tqdir.h>
#include <tqdatetime.h>
-#include <kstandarddirs.h>
+#include <tdestandarddirs.h>
#include <tdelocale.h>
#include <tdeconfig.h>
#include <kdebug.h>
@@ -388,7 +388,7 @@ bool ColorSchema::rereadSchemaFile()
if (!(0 <= fi && fi <= TABLE_COLORS)) continue;
if (!(0 <= tr && tr <= 1 )) continue;
if (!(0 <= bo && bo <= 1 )) continue;
- m_table[fi].color = kapp->palette().active().text();
+ m_table[fi].color = tdeApp->palette().active().text();
m_table[fi].transparent = tr;
m_table[fi].bold = bo;
}
@@ -399,7 +399,7 @@ bool ColorSchema::rereadSchemaFile()
if (!(0 <= fi && fi <= TABLE_COLORS)) continue;
if (!(0 <= tr && tr <= 1 )) continue;
if (!(0 <= bo && bo <= 1 )) continue;
- m_table[fi].color = kapp->palette().active().base();
+ m_table[fi].color = tdeApp->palette().active().base();
m_table[fi].transparent = tr;
m_table[fi].bold = bo;
}
diff --git a/konsole/konsole/session.h b/konsole/konsole/session.h
index 3b5f211fa..0b4dbed50 100644
--- a/konsole/konsole/session.h
+++ b/konsole/konsole/session.h
@@ -31,7 +31,7 @@
#include "sessioniface.h"
-class KProcIO;
+class TDEProcIO;
class TDEProcess;
class ZModemDialog;
@@ -222,7 +222,7 @@ private:
// ZModem
bool zmodemBusy;
- KProcIO* zmodemProc;
+ TDEProcIO* zmodemProc;
ZModemDialog* zmodemProgress;
// Color/Font Changes by ESC Sequences
diff --git a/konsole/terminalhere/terminalhere.cpp b/konsole/terminalhere/terminalhere.cpp
index 7b178c846..0fffd7538 100644
--- a/konsole/terminalhere/terminalhere.cpp
+++ b/konsole/terminalhere/terminalhere.cpp
@@ -32,7 +32,7 @@ TerminalHere::TerminalHere() : TDEApplication()
{
TDECmdLineArgs *args = TDECmdLineArgs::parsedArgs();
- TDEConfig *config = kapp->config();
+ TDEConfig *config = tdeApp->config();
config->setGroup("General");
TQString term = config->readPathEntry("TerminalApplication", "konsole");
diff --git a/konsole/konsole/session.cpp b/konsole/konsole/session.cpp
index d613a23e4..4a3b1975e 100644
--- a/konsole/konsole/session.cpp
+++ b/konsole/konsole/session.cpp
@@ -26,10 +26,10 @@
#include <tdemessagebox.h>
#include <knotifyclient.h>
#include <tdelocale.h>
-#include <kprocio.h>
+#include <tdeprocio.h>
#include <krun.h>
#include <kshell.h>
-#include <kstandarddirs.h>
+#include <tdestandarddirs.h>
#include <stdlib.h>
#include <tqfile.h>
@@ -181,7 +181,7 @@ void TESession::run()
return;
}
- TQString appId=kapp->dcopClient()->appId();
+ TQString appId=tdeApp->dcopClient()->appId();
TQString cwd_save = TQDir::currentDirPath();
if (!initial_cwd.isEmpty())
@@ -624,7 +624,7 @@ void TESession::cancelZModem()
void TESession::startZModem(const TQString &zmodem, const TQString &dir, const TQStringList &list)
{
zmodemBusy = true;
- zmodemProc = new KProcIO;
+ zmodemProc = new TDEProcIO;
(*zmodemProc) << zmodem << "-v";
for(TQStringList::ConstIterator it = list.begin();
@@ -636,9 +636,9 @@ void TESession::startZModem(const TQString &zmodem, const TQString &dir, const T
if (!dir.isEmpty())
zmodemProc->setWorkingDirectory(dir);
- zmodemProc->start(KProcIO::NotifyOnExit, false);
+ zmodemProc->start(TDEProcIO::NotifyOnExit, false);
- // Override the read-processing of KProcIO
+ // Override the read-processing of TDEProcIO
disconnect(zmodemProc,TQ_SIGNAL (receivedStdout (TDEProcess *, char *, int)), 0, 0);
connect(zmodemProc,TQ_SIGNAL (receivedStdout (TDEProcess *, char *, int)),
this, TQ_SLOT(zmodemSendBlock(TDEProcess *, char *, int)));